#!/bin/csh
#SBATCH --ntasks=1
#SBATCH -N 1 
#SBATCH --job-name=HB-intra
#SBATCH -t 08:00:00

# Authors: Xiaohong Zhuang, Dr.Jefferey B. Klauda
#    Date: 4/15/2016

unset noclobber
cd $SLURM_SUBMIT_DIR

module load openmpi/1.6
module load fftw/3.3.3/gnu/4.6.1/openmpi/1.6/shared
setenv LD_LIBRARY_PATH $FFTWLIB
hostname

# INVOKE CHARMM
# In DT1
# set chm = "/lustre/home/jbklauda/charmm/c39a2wxw/myc39a2/exec/gnu_M/gfortcol.om"
# In DT2
set chm = "/homes/aleonar2/charmm/c41b2/exec/gnu_M/charmm"

###############################################################################################################
# UPDATE REGION

# Update the path of the file based on your system
set sdir = "/lustre/mda003/hlms_310.15/pe_pc_nsm_chol/a_traj"

# Update the equilibrated dcd file range based on your system
@ f = 101       # first dcd file to read
@ l = 150       # last dcd file to read

# 1. Update lipid type [type] for Glycerol lipids:G ;                Sphingo lipids:S ;  
# 2. Update lipid resdue name [rn]  
# 3. Update headgroups [h] for Glycerol lipids:PA/PC/PE/PG/PI/PS;    Sphingo lipids: SM/CER ;
# 4. For glycerol lipids, specify the following for the lipid tails:
#      a) If there is a carbonyl moiety [iscrb] as Y (usually case), otherwise N (if one tail of each, use Y)
#      b) If there is no tail (just an alcohol group) [islys] as Y, otherwise N (if one tail of each, use Y)
# DON'T include the sterol,cholestrol lipids here as it has no H acceptor, so no intralipid HB.
# DON'T include the PC glycerol lipids here as it has no H donor, so no intralipid HB.
# Exception: lyso PC lipid should be included, as alcohol group provides H donor

# List lipids in your system that have both H donor and acceptor for intra-lipid H-bonding
$chm f=$f l=$l p=${sdir} type=G rn=DOPE h=PE iscrb=Y islys=N < 1_calc_hb_intra.inp >& 1_calc_hb_intra-DOPE.out
$chm f=$f l=$l p=${sdir} type=S rn=NSM  h=SM                 < 1_calc_hb_intra.inp >& 1_calc_hb_intra-NSM.out

##################################################################################################################

# Calculate total number of dyns
@ N = ($l - $f + 1)
echo $N > Ndyn.txt
