#!/bin/csh
#SBATCH --ntasks=1
#SBATCH -N 1 
#SBATCH --job-name=HB-All
#SBATCH -t 06:00:00

# Authors: Xiaohong Zhuang, Dr.Jefferey B. Klauda
#    Date: 4/15/2016

unset noclobber
cd $SLURM_SUBMIT_DIR

module load openmpi/1.6
module load fftw/3.3.3/gnu/4.6.1/openmpi/1.6/shared
setenv LD_LIBRARY_PATH $FFTWLIB
hostname

# INVOKE CHARMM
# In DT1
# set chm = "/lustre/home/jbklauda/charmm/c39a2wxw/myc39a2/exec/gnu_M/gfortcol.om"
# In DT2
set chm = "/homes/aleonar2/charmm/c41b2/exec/gnu_M/charmm"

################################################################################################################
# UPDATE REGION

# Update the path of the file
set sdir = "/lustre/mda003/hlms_310.15/pe_pc_nsm_chol/a_traj"

# Update the equilibrated dcd file range
@ f = 101       # first dcd file to read
@ l = 150       # last dcd file to read

# Lipid type for Glycerol lipids:G ;                Sphingo lipids:S ;           Sterol/Cholestrol lipids: C ; 
# headgroups for Glycerol lipids:PA/PC/PE/PG/PI/PS; Sphingo lipids: SM/CER ;
# DON'T put PC lipid here as it has no H donor, but included PC lipids in 1_calc_hb_all.inp as it is H acceptor.
# Exception: lyso PC lipid should be included, since alcohol group gives H donor

# Update the lipids with H donors with lipid_type, lipid_name, and headgroup in each of the following lines
# For glycerol lipids: specify [islys], as with part 1 of the script (but [iscrb] not specified here)
# Donot need to specify headgroup for Sterol lipids

$chm f=$f l=$l p=${sdir} type=C rn=CHL1              < 1_calc_hb_all.inp >& 1_calc_hb_all_CHL1.out
$chm f=$f l=$l p=${sdir} type=G rn=DOPE h=PE islys=N < 1_calc_hb_all.inp >& 1_calc_hb_all_DOPE.out
$chm f=$f l=$l p=${sdir} type=S rn=NSM  h=SM         < 1_calc_hb_all.inp >& 1_calc_hb_all_NSM.out

############################################################################################################

# Calculate total number of dyns
@ N = ($l - $f + 1)
echo $N > Ndyn.txt

